@@ -1,9 +1,9 @@
 import os
-import hashlib
 import yaml
+from batman.yaml_ordered_dict import OrderedDictYAMLLoader
 
 
 def load(filename):
     with open(os.path.expanduser(filename)) as f:
-        out = yaml.load(f)
+        out = yaml.load(f, Loader=OrderedDictYAMLLoader)
         return out
